# Changelog

All notable changes to `timeseriesdatasets` will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2026-02-23

### Added
- Initial release of `timeseriesdatasets`
- Access to a curated collection of time series datasets for data analysis, forecasting, statistical analysis, and machine learning in Python.
- Basic documentation and usage examples
